# Copyright 2005 James Bunton <james@delx.cjb.net>
# Licensed for distribution under the GPL version 2, check COPYING for details


import os
import errno
from epollc import *


class ePollError(Exception):
	def __init__(self, value):
		self.value = value
	
	def __str__(self):
		return repr(self.value)


class ePoller:
	def __init__(self, size=1024):
		ret = epoll_create(size)
		if(type(ret) == int):
			self.epfd = ret
		else:
			raise ePollError(ret[1])
	
	def __del__(self):
		self.close()
	
	def register(self, fd, eventMask):
		self._doCtl(EPOLL_CTL_ADD, fd, eventMask)
	
	def modregister(self, fd, eventMask):
		self._doCtl(EPOLL_CTL_MOD, fd, eventMask)

	def unregister(self, fd):
		self._doCtl(EPOLL_CTL_DEL, fd, 0)

	def _doCtl(self, action, fd, eventMask):
		if(hasattr(fd, "fileno")):
			fd = fd.fileno()
		ret = epoll_ctl(self.epfd, action, fd, eventMask)
		if(ret):
			raise ePollError(ret[1])
	
	def poll(self, timeout, maxevents=128):
		ret = epoll_wait(self.epfd, maxevents, timeout)
		if(type(ret) == list):
			return ret
		else:
			raise ePollError(ret[1])
	
	def close(self):
		f = os.fdopen(self.epfd)
		f.close()


